import argparse


parser = argparse.ArgumentParser(description=(
                                            f"Have fun in particular N-Body simulations."
                                            f"Brought to you by sail.black ")
                                            )
parser.add_argument('--exp_name', type=str, default='exp_1', metavar='N', help='experiment_name')
parser.add_argument('--batch_size', type=int, default=100, metavar='N',
                    help='input batch size for training (default: 128)')
parser.add_argument('--epochs', type=int, default=10000, metavar='N',
                    help='number of epochs to train (default: 10)')

args = parser.parse_args()


def main():
    
    # The idea is to implement a better Config adapter and then use the self-made cli to run it

    if args.model == 'gnn':
    



if __name__ == "__main__":
    main()





import numpy as np
from amarium import make_full_filename, delete_file



from particular.monte_carlo.monte_carlo_init import init_lj

def test_lj(): 
    delete_file("Simulations/MCInit/LJ_pos_128.npy")
    
    number_particles = 128
    epsilon = 0.25
    sigma = 0.25 
    box_len = 8
    file_name = f"LJ_pos_{number_particles}"
    
    dir_name = "Simulations/MCInit"
    ref_name = make_full_filename(prefix = dir_name, file_name = file_name) + ".npy"
    init_lj(sigma = sigma, 
            epsilon = epsilon, 
            number_particles = number_particles, 
            box_len = box_len, 
            file_name = file_name, 
            dir_name = dir_name)

    data = np.load("Simulations/MCInit/LJ_pos_128.npy")
    assert len(data) == number_particles, str(data.shape)